summaryrefslogtreecommitdiffstats
path: root/parts/filecreate/filecreate_part.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parts/filecreate/filecreate_part.cpp')
-rw-r--r--parts/filecreate/filecreate_part.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/parts/filecreate/filecreate_part.cpp b/parts/filecreate/filecreate_part.cpp
index 1c371177..a1529097 100644
--- a/parts/filecreate/filecreate_part.cpp
+++ b/parts/filecreate/filecreate_part.cpp
@@ -54,16 +54,16 @@
#include "config.h"
-static const KDevPluginInfo data("kdevfilecreate");
+static const KDevPluginInfo pluginData("kdevfilecreate");
typedef KDevGenericFactory<FileCreatePart> FileCreateFactory;
-K_EXPORT_COMPONENT_FACTORY( libkdevfilecreate, FileCreateFactory( data ) )
+K_EXPORT_COMPONENT_FACTORY( libkdevfilecreate, FileCreateFactory( pluginData ) )
using namespace FileCreate;
FileCreatePart::FileCreatePart(TQObject *parent, const char *name, const TQStringList & )
-// : KDevCreateFile(&data, parent, name ? name : "FileCreatePart"), m_selectedWidget(-1), m_useSideTab(true), m_subPopups(0)
- : KDevCreateFile(&data, parent, name ? name : "FileCreatePart"), m_subPopups(0)
+// : KDevCreateFile(&pluginData, parent, name ? name : "FileCreatePart"), m_selectedWidget(-1), m_useSideTab(true), m_subPopups(0)
+ : KDevCreateFile(&pluginData, parent, name ? name : "FileCreatePart"), m_subPopups(0)
{
setInstance(FileCreateFactory::instance());
setXMLFile("kdevpart_filecreate.rc");